/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.fluo.api.data;

import java.nio.charset.StandardCharsets;

class AsciiSequence implements CharSequence {


  private final int len;
  private final int offset;
  private final byte[] chars;

  public AsciiSequence(byte[] chars, int offset, int len) {
    this.len = len;
    this.offset = offset;
    this.chars = chars;
  }

  public AsciiSequence(String s) {
    chars = s.getBytes(StandardCharsets.US_ASCII);
    len = chars.length;
    offset = 0;
  }

  @Override
  public int length() {
    return len;
  }

  @Override
  public char charAt(int index) {
    return (char) chars[index];
  }

  @Override
  public CharSequence subSequence(int start, int end) {
    return new AsciiSequence(chars, offset + start, end - start);
  }

}
