/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.fluo.command;

import com.beust.jcommander.Parameters;
import org.apache.fluo.api.config.FluoConfiguration;
import org.apache.fluo.core.client.FluoAdminImpl;

@Parameters(commandNames = "status",
    commandDescription = "Prints status of Fluo application for <app>")
public class FluoStatus extends AppCommand {

  @Override
  public void execute() throws FluoCommandException {
    FluoConfiguration config = getConfig();
    try (FluoAdminImpl admin = new FluoAdminImpl(config)) {
      if (!admin.zookeeperInitialized()) {
        System.out.println("NOT_FOUND");
      } else if (admin.applicationRunning()) {
        System.out.println("RUNNING");
      } else {
        System.out.println("STOPPED");
      }
    }
  }
}
